# Kinto Admin

## What's wrong?

The Kinto-Admin UI is a JavaScript project which is not fully delivered with the server source code.

## Build and run locally

In order to get a local Kinto Admin running at this address, just run the following command:

`make build-kinto-admin`

Restart the server and refresh!

## ...or use our online version!

The Kinto Admin is a fully static Web application. That means you can use the online version on your local server. Just navigate to http://kinto.github.io/kinto-admin/ and set the server address to http://localhost:8888/v1.